@@ -31,6 +31,8 @@ c_icap_start() {
 
 c_icap_test_basic() {
   echo 'Testing c-icap'
+  # Let the service get time to start before reading pid file
+  /bin/sleep 0.1
   pidof /usr/bin/c-icap > /dev/null || die 'c-icap is not running'
   test -f /var/run/c-icap/c-icap.pid || error 'PidFile missing'
   test -p /var/run/c-icap/c-icap.ctl || error 'CommandsSocket missing'
